<?php

declare(strict_types=1);

namespace Dedi\SyliusBlogPlugin\Controller\Api;

use ApiPlatform\Api\IriConverterInterface;
use Dedi\SyliusBlogPlugin\Domain\Blog\Adapter\BlogUploadAwareRepositoryInterface;
use Dedi\SyliusBlogPlugin\Entity\ArticleInterface;
use Sylius\Component\Core\Model\ImageInterface;
use Sylius\Component\Core\Uploader\ImageUploaderInterface;
use Sylius\Component\Resource\Factory\FactoryInterface;
use Sylius\Component\Resource\Model\ResourceInterface;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\Request;
use Webmozart\Assert\Assert;

class UploadArticleBannerAction extends AbstractController
{
    public function __construct(
        private readonly FactoryInterface $articleBannerFactory,
        private readonly BlogUploadAwareRepositoryInterface $articleBannerRepository,
        private readonly ImageUploaderInterface $imageUploader,
        private readonly IriConverterInterface $iriConverter,
    ) {
    }

    public function __invoke(Request $request): ImageInterface
    {
        $file = $request->files->get('file');

        /** @var ImageInterface $image */
        $image = $this->articleBannerFactory->createNew();
        $image->setFile($file);

        /** @var string $ownerIri */
        $ownerIri = $request->request->get('owner');
        Assert::notEmpty($ownerIri);

        /** @var ResourceInterface|ArticleInterface $owner */
        $owner = $this->iriConverter->getResourceFromIri($ownerIri);
        Assert::isInstanceOf($owner, ArticleInterface::class);

        $oldImage = $owner->getBanner();
        if ($oldImage !== null) {
            $this->articleBannerRepository->remove($oldImage);
        }
        $owner->setBanner($image);

        $this->imageUploader->upload($image);

        return $image;
    }
}
