<?php

declare(strict_types=1);

namespace Dedi\SyliusBlogPlugin\Entity;

use Sylius\Component\Core\Model\ChannelInterface;
use Sylius\Component\Core\Model\ImageInterface;

class BlogConfiguration extends AbstractReferable implements BlogConfigurationInterface
{
    protected ?int $id = null;

    protected bool $headerDisplayable = true;

    protected ?ImageInterface $banner = null;

    protected ?ChannelInterface $channel = null;

    public function getId(): ?int
    {
        return $this->id;
    }

    public function isHeaderDisplayable(): bool
    {
        return $this->headerDisplayable;
    }

    public function getBanner(): ?ImageInterface
    {
        return $this->banner;
    }

    public function setBanner(?ImageInterface $banner): self
    {
        $banner?->setOwner($this);
        $this->banner = $banner;

        return $this;
    }

    public function setHeaderDisplayable(bool $headerDisplayable): self
    {
        $this->headerDisplayable = $headerDisplayable;

        return $this;
    }

    public function getTitle(): ?string
    {
        /** @var BlogConfigurationTranslationInterface $translation */
        $translation = $this->getTranslation();

        return $translation->getTitle();
    }

    public function setTitle(?string $title): self
    {
        /** @var BlogConfigurationTranslationInterface $translation */
        $translation = $this->getTranslation();
        $translation->setTitle($title);

        return $this;
    }

    public function getDescription(): ?string
    {
        /** @var BlogConfigurationTranslationInterface $translation */
        $translation = $this->getTranslation();

        return $translation->getDescription();
    }

    public function setDescription(?string $description): self
    {
        /** @var BlogConfigurationTranslationInterface $translation */
        $translation = $this->getTranslation();
        $translation->setDescription($description);

        return $this;
    }

    public function getChannel(): ?ChannelInterface
    {
        return $this->channel;
    }

    public function setChannel(?ChannelInterface $channel): self
    {
        $this->channel = $channel;

        return $this;
    }

    public function getTranslation(?string $locale = null): AbstractReferableTranslation
    {
        /** @var BlogConfigurationTranslation $translation */
        $translation = parent::getTranslation($locale);

        return $translation;
    }

    protected function createTranslation(): BlogConfigurationTranslation
    {
        return new BlogConfigurationTranslation();
    }
}
